# Generated by Django 3.2.15 on 2022-08-19 15:17

import ckeditor_uploader.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0009_auto_20220818_2156'),
    ]

    operations = [
        migrations.CreateModel(
            name='PaymentOption',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('short_name', models.CharField(max_length=255, unique=True, verbose_name='Kurzname')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('notice', ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Wird unter der Option angezeigt', verbose_name='Anmerkung')),
                ('email_notice', ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Wird in der Bestätigungs-E-Mail angezeigt', verbose_name='E-Mail-Bemerkung')),
                ('price', models.FloatField(validators=[django.core.validators.MinValueValidator(0.0)])),
            ],
            options={
                'verbose_name': 'Payment option',
                'verbose_name_plural': 'Payment options',
            },
        ),
        migrations.RenameModel("ProcessingOption", "ShippingOption"),
        migrations.RenameModel("ProcessingOptionPrice", "ShippingOptionPrice"),
    ]
