# Generated by Django 3.2.16 on 2022-11-09 20:29

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0011_auto_20220819_1742'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='order',
            options={'permissions': [('manage_orders', 'Can manage orders')], 'verbose_name': 'Order', 'verbose_name_plural': 'Orders'},
        ),
        migrations.AlterModelOptions(
            name='orderform',
            options={'permissions': [('manage_orders_of_form', 'Can manage orders of form')], 'verbose_name': 'Order form', 'verbose_name_plural': 'Order forms'},
        ),
        migrations.AddField(
            model_name='item',
            name='image',
            field=models.ImageField(blank=True, null=True, upload_to='order/items', verbose_name='Image'),
        ),
        migrations.AlterField(
            model_name='item',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='item',
            name='notice',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Shown below the item', verbose_name='Notice'),
        ),
        migrations.AlterField(
            model_name='item',
            name='short_name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Short name'),
        ),
        migrations.AlterField(
            model_name='order',
            name='email',
            field=models.EmailField(max_length=254, verbose_name='Email'),
        ),
        migrations.AlterField(
            model_name='order',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='order',
            name='notes',
            field=models.TextField(blank=True, verbose_name='Notes'),
        ),
        migrations.AlterField(
            model_name='order',
            name='place',
            field=models.CharField(blank=True, max_length=255, verbose_name='Place'),
        ),
        migrations.AlterField(
            model_name='order',
            name='sent',
            field=models.BooleanField(default=False, verbose_name='Sent'),
        ),
        migrations.AlterField(
            model_name='order',
            name='shipping_option',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='order.shippingoption', verbose_name='Selected shipping option'),
        ),
        migrations.AlterField(
            model_name='order',
            name='street',
            field=models.CharField(blank=True, max_length=255, verbose_name='Street'),
        ),
        migrations.AlterField(
            model_name='orderform',
            name='available_shipping_options',
            field=models.ManyToManyField(related_name='forms', to='order.ShippingOption', verbose_name='Available shipping options'),
        ),
        migrations.AlterField(
            model_name='orderform',
            name='help_text',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text="Shown in the form's footer", verbose_name='Help text'),
        ),
        migrations.AlterField(
            model_name='orderform',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='orderitem',
            name='count',
            field=models.IntegerField(verbose_name='Count'),
        ),
        migrations.AlterField(
            model_name='orderitem',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='orderitem',
            name='order',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='items', to='order.order', verbose_name='Order'),
        ),
        migrations.AlterField(
            model_name='paymentoption',
            name='email_notice',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Shown in the confirmation email', verbose_name='Email notice'),
        ),
        migrations.AlterField(
            model_name='paymentoption',
            name='notice',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Shown below the option', verbose_name='Notice'),
        ),
        migrations.AlterField(
            model_name='paymentoption',
            name='short_name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Short name'),
        ),
        migrations.AlterField(
            model_name='shippingoption',
            name='address_necessary',
            field=models.BooleanField(default=False, verbose_name='Address necessary'),
        ),
        migrations.AlterField(
            model_name='shippingoption',
            name='email_notice',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Shown in the confirmation email', verbose_name='Email notice'),
        ),
        migrations.AlterField(
            model_name='shippingoption',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='shippingoption',
            name='notice',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, help_text='Shown below the option', verbose_name='Notice'),
        ),
        migrations.AlterField(
            model_name='shippingoption',
            name='short_name',
            field=models.CharField(max_length=255, unique=True, verbose_name='Short name'),
        ),
        migrations.AlterField(
            model_name='shippingoptionprice',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='shippingoptionprice',
            name='option',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='prices', to='order.shippingoption', verbose_name='Shipping option'),
        ),
    ]
