# Generated by Django 3.2.18 on 2023-03-09 20:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0018_auto_20221231_1841'),
    ]

    operations = [
        migrations.AlterField(
            model_name='digitalproductshare',
            name='share_expiration',
            field=models.DateTimeField(verbose_name='Share expiration'),
        ),
        migrations.AlterField(
            model_name='order',
            name='digital_products_key',
            field=models.TextField(blank=True, verbose_name='Digital products key'),
        ),
    ]
