# Generated by Django 3.2.15 on 2022-08-18 19:56

import ckeditor_uploader.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0008_auto_20210121_1154'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='count_for_shipping',
            field=models.BooleanField(default=True, verbose_name='Count for shipping'),
        ),
    ]
