# Generated by Django 3.2.15 on 2022-08-19 15:42

import ckeditor_uploader.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0010_auto_20220819_1717'),
    ]

    operations = [
        migrations.RenameField(
            model_name='order',
            old_name='processing_option',
            new_name='shipping_option',
        ),
        migrations.RenameField(
            model_name='orderform',
            old_name='available_processing_options',
            new_name='available_shipping_options',
        ),
        migrations.AddField(
            model_name='order',
            name='payment_option',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='order.paymentoption', verbose_name='Selected payment option'),
        ),
        migrations.AddField(
            model_name='orderform',
            name='available_payment_options',
            field=models.ManyToManyField(related_name='forms', to='order.PaymentOption', verbose_name='Available payment options'),
        ),
    ]
