# Generated by Django 3.2.16 on 2022-12-22 12:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0014_order_person'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='order',
            field=models.IntegerField(default=0, verbose_name='Order'),
        ),
    ]
