# Generated by Django 3.2.16 on 2022-12-14 19:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0012_auto_20221109_2129'),
    ]

    operations = [
        migrations.AddField(
            model_name='item',
            name='digital_product',
            field=models.BooleanField(default=False, verbose_name='Digital product'),
        ),
        migrations.AddField(
            model_name='shippingoption',
            name='for_digital_products',
            field=models.BooleanField(default=False, verbose_name='For digital products'),
        ),
    ]
