# Generated by Django 3.2.16 on 2022-12-31 13:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0016_auto_20221231_1319'),
    ]

    operations = [
        migrations.CreateModel(
            name='DigitalProductShare',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('share_id', models.CharField(max_length=255, verbose_name='Share ID')),
                ('share_url', models.URLField(verbose_name='Share URL')),
                ('share_expiration', models.DateField(verbose_name='Share expiration')),
                ('order_item', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='order.orderitem', verbose_name='Order item')),
            ],
            options={
                'verbose_name': 'Digital product share',
                'verbose_name_plural': 'Digital product shares',
            },
        ),
    ]
