# Generated by Django 5.0.8 on 2024-08-24 14:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0019_auto_20230309_2157'),
    ]

    operations = [
        migrations.AddField(
            model_name='digitalproduct',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='digitalproductshare',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='item',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='nextcloudprovider',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='order',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='orderform',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='orderitem',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='paymentoption',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='shippingoption',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
        migrations.AddField(
            model_name='shippingoptionprice',
            name='managed_by_app_label',
            field=models.CharField(blank=True, editable=False, max_length=255, verbose_name='App label of app responsible for managing this instance'),
        ),
    ] + [
        migrations.RunSQL(
            f"ALTER TABLE order_{model_name} drop column if exists site_id;"
        ) for model_name  in
        [
            "nextcloudprovider",
            "digitalproductshare",
            "digitalproduct",
            "item",
            "paymentoption",
            "shippingoption",
            "shippingoptionprice",
            "orderform",
            "order",
            "orderitem",
        ]
    ]
