# Generated by Django 3.2.16 on 2022-12-22 11:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0013_auto_20221214_2054'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='person',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='core.person', verbose_name='Person'),
        ),
    ]
