# Generated by Django 3.2.16 on 2022-12-31 17:41
import uuid

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('order', '0017_digitalproductshare'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='digital_products_key',
            field=models.TextField(blank=True, verbose_name='Digital products key', default=uuid.uuid4),
        ),
        migrations.AlterField(
            model_name='digitalproductshare',
            name='order_item',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='shares', to='order.orderitem', verbose_name='Order item'),
        ),
    ]
